@@ -1,17 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "7c19a38db7111a519c3d027dd728d33cedc266bb",
-  "branchName": "release-client-5.15.1",
-  "buildTime": "2023-06-27 06:12:35 GMT",
-  "buildVersion": "5.1.454",
+  "commitId": "9683fc039855b27aa0a503201915ba5ab6bda492",
+  "branchName": "release-client-5.17.x",
+  "buildTime": "2023-12-21 07:52:04 GMT",
+  "buildVersion": "5.1.977",
   "css": [
-    "@zoom/client-calendar/static/css/default~app.23947beb.css",
-    "@zoom/client-calendar/static/css/vendors~app.dc891ce4.css"
+    "@zoom/client-calendar/static/css/chunk-vendors.974eca6e.css",
+    "@zoom/client-calendar/static/css/app.7c5cc38c.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/default~app.e3e199ec.js",
-    "@zoom/client-calendar/static/js/vendors~app.f21e2e32.js",
-    "@zoom/client-calendar/static/js/app.7878aa6b.js"
+    "@zoom/client-calendar/static/js/chunk-vendors.9eb0a6bb.js",
+    "@zoom/client-calendar/static/js/app.0e7eb3ae.js"
   ],
   "key": "@zoom/client-calendar"
 };
