@@ -1,17 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "3758788d944fa31fc200f97a4ef751cb74654b1c",
-  "branchName": "release-client-5.x",
-  "buildTime": "Sat, 17 Jun 2023 12:11:02 GMT",
-  "buildVersion": "5.1.272",
+  "commitId": "ab8860ae518804bcd3656d422398eca6d634e868",
+  "branchName": "release-client-5.17.x",
+  "buildTime": "2023-12-21 11:04:58 GMT",
+  "buildVersion": "5.17.566",
   "css": [
-    "@zoom/client-scheduler/static/css/chunk-vendors.af34567c.css",
-    "@zoom/client-scheduler/static/css/index.39b774a5.css"
+    "@zoom/client-scheduler/static/css/chunk-vendors.2c78868d.css",
+    "@zoom/client-scheduler/static/css/index.b89d0556.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.c685a8ed.js",
-    "@zoom/client-scheduler/static/js/index.2231e223.js"
-  ]
+    "@zoom/client-scheduler/static/js/chunk-vendors.7e66a338.js",
+    "@zoom/client-scheduler/static/js/index.b15344d6.js"
+  ],
+  "key": "clientSchedulerResource"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
